@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_EVENTVIEW_H
 #define EVENTVIEWS_EVENTVIEW_H
@@ -32,19 +16,14 @@
 #include <Item>
 #include <Akonadi/Calendar/ETMCalendar>
 
-#include <KCalCore/Incidence>
-#include <KCalCore/Todo>
+#include <KCalendarCore/Incidence>
+#include <KCalendarCore/Todo>
 
 #include <QWidget>
 #include <QSet>
 #include <QByteArray>
 #include <QDate>
 
-namespace KCalCore {
-template<typename T> class SortableList;
-typedef SortableList<QDate> DateList;
-}
-
 namespace CalendarSupport {
 class CollectionSelection;
 class KCalPrefs;
@@ -133,7 +112,7 @@ public:
 
     /**
       Return calendar object of this view.
-      TODO: replace with a version that returns a KCalCore::Calendar so it
+      TODO: replace with a version that returns a KCalendarCore::Calendar so it
             can be used in different environments.
             see agendaview for example calendar2(incidence)
     */
@@ -160,7 +139,7 @@ public:
       probably only select a single event at a time, but some may be able
       to select more than one.
     */
-    virtual KCalCore::DateList selectedIncidenceDates() const = 0;
+    virtual KCalendarCore::DateList selectedIncidenceDates() const = 0;
 
     /**
        Returns the start of the selection, or an invalid QDateTime if there is no selection
@@ -270,7 +249,7 @@ public:
     Q_REQUIRED_RESULT QDateTime actualStartDateTime() const;
     Q_REQUIRED_RESULT QDateTime actualEndDateTime() const;
 
-    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalCore::Incidence::Ptr &incidence, const QDate &date);
+    Q_REQUIRED_RESULT int showMoveRecurDialog(const KCalendarCore::Incidence::Ptr &incidence, const QDate &date);
 
     /**
       Handles key events, opens the new event dialog when enter is pressed, activates type ahead.
@@ -369,7 +348,7 @@ Q_SIGNALS:
      * selected dates has changed.
      *   @param datelist the new list of selected dates
      */
-    void datesSelected(const KCalCore::DateList &datelist);
+    void datesSelected(const KCalendarCore::DateList &datelist);
 
     /**
      * Emitted when an event is moved using the mouse in an agenda
@@ -474,7 +453,7 @@ private:
     void onCollectionChanged(const Akonadi::Collection &, const QSet<QByteArray> &);
 
 protected:
-    bool makesWholeDayBusy(const KCalCore::Incidence::Ptr &incidence) const;
+    bool makesWholeDayBusy(const KCalendarCore::Incidence::Ptr &incidence) const;
     Akonadi::IncidenceChanger *changer() const;
 
     /**
